# ApplicationAssignment

Application assignment's properties
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | The unique identifier for the assignment. | [optional] [readonly] 
**org_id** | **str** | The unique identifier for the organisation which is being given access to the application environment.  | 
**environment_name** | **str** | The name of the environment of the application for which to give access.  | 
**application_name** | **str** | The display name for the application for which to give access. Provided on get for convenience. Do not set the field for modifying operations as it will be ignored.  | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


